@@ -225,9 +225,9 @@ var app = new Vue({
     data: function () {
         var current = this.parseHash();
         return {
-            hasCollections: null,
-            currentCollection: current.collection || null,
-            collections: {},
+            hasSchema: null,
+            currentSchemaName: current.schema || null,
+            schema: {},
             openedRow: null,
             deleteIndex: null,
             addingItem: false,
@@ -244,7 +244,8 @@ var app = new Vue({
             sortColumn: null,
             sortDirection: 1,
             newFilter: null,
-            filters: []
+            filters: [],
+            toasts: []
         }
     },
     methods: {
@@ -299,8 +300,8 @@ var app = new Vue({
             this.fetchPage();
         },
 
-        setCollection: function ( name ) {
-            this.currentCollection = name;
+        setSchema: function ( name ) {
+            this.currentSchemaName = name;
             $( '#sidebar-collapse' ).collapse('hide');
         },
 
@@ -315,9 +316,9 @@ var app = new Vue({
         },
 
         parseSpec: function ( spec ) {
-            var pathParts = [], collectionName, collection, pathObj, firstCollection;
-            this.collections = {};
-            this.hasCollections = false;
+            var pathParts = [], schemaName, schema, pathObj, firstSchema;
+            this.schema = {};
+            this.hasSchema = false;
 
             // Preprocess definitions
             for ( var defKey in spec.definitions ) {
@@ -371,74 +372,73 @@ var app = new Vue({
                 pathObj = spec.paths[ pathKey ];
 
                 pathParts = pathKey.split( '/' );
-                collectionName = pathParts[1];
+                schemaName = pathParts[1];
 
-                // Skip hidden collections
-                if ( spec.definitions[ collectionName ]['x-hidden'] ) {
+                // Skip hidden schemas
+                if ( spec.definitions[ schemaName ]['x-hidden'] ) {
                     continue;
                 }
 
-                collection = this.collections[ collectionName ];
-                if ( !collection ) {
-                    collection = this.collections[ collectionName ] = {
+                schema = this.schema[ schemaName ];
+                if ( !schema ) {
+                    schema = this.schema[ schemaName ] = {
                         operations: { }
                     };
                 }
-                if ( !firstCollection ) {
-                    firstCollection = collectionName;
+                if ( !firstSchema ) {
+                    firstSchema = schemaName;
                 }
-                this.hasCollections = true;
+                this.hasSchema = true;
 
                 // Array operations
                 if ( pathParts.length == 2 ) {
                     if ( pathObj.get ) {
-                        collection.operations["list"] = {
+                        schema.operations["list"] = {
                             url: [ spec.basePath, pathKey ].join(''),
-                            schema: spec.definitions[ collectionName ]
+                            schema: spec.definitions[ schemaName ]
                         };
                     }
                     if ( pathObj.post ) {
-                        collection.operations["add"] = {
+                        schema.operations["add"] = {
                             url: [ spec.basePath, pathKey ].join(''),
-                            schema: spec.definitions[ collectionName ]
+                            schema: spec.definitions[ schemaName ]
                         };
                     }
                 }
                 // Item operations
                 else {
                     if ( pathObj.get ) {
-                        collection.operations["get"] = {
+                        schema.operations["get"] = {
                             url: [ spec.basePath, pathKey ].join(''),
-                            schema: spec.definitions[ collectionName ]
+                            schema: spec.definitions[ schemaName ]
                         };
                     }
                     if ( pathObj.put ) {
-                        collection.operations["set"] = {
+                        schema.operations["set"] = {
                             url: [ spec.basePath, pathKey ].join(''),
-                            schema: spec.definitions[ collectionName ]
+                            schema: spec.definitions[ schemaName ]
                         };
                     }
                     if ( pathObj.delete ) {
-                        collection.operations["delete"] = {
+                        schema.operations["delete"] = {
                             url: [ spec.basePath, pathKey ].join(''),
-                            schema: spec.definitions[ collectionName ]
+                            schema: spec.definitions[ schemaName ]
                         };
                     }
                 }
             }
 
-            if ( this.currentCollection && this.collections[ this.currentCollection ] ) {
+            if ( this.currentSchemaName && this.schema[ this.currentSchemaName ] ) {
                 this.fetchPage();
             }
             else {
-                this.currentCollection = firstCollection;
+                this.currentSchemaName = firstSchema;
             }
         },
 
         fetchPage: function () {
             if ( this.fetching ) return;
-            var coll = this.collections[ this.currentCollection ],
-                self = this,
+            var self = this,
                 query = {
                     $limit: this.perPage,
                     $offset: this.perPage * ( this.currentPage - 1 )
@@ -454,7 +454,7 @@ var app = new Vue({
 
             this.fetching = true;
             delete this.error.fetchPage;
-            $.get( coll.operations["list"].url, query ).done(
+            $.get( this.currentOperations["list"].url, query ).done(
                 function ( data, status, jqXHR ) {
                     if ( query.offset > data.total ) {
                         // We somehow got to a page that doesn't exist,
@@ -467,7 +467,7 @@ var app = new Vue({
 
                     self.items = data.items;
                     self.total = data.total;
-                    self.columns = self.getListColumns( self.currentCollection ),
+                    self.columns = self.getListColumns( self.currentSchemaName ),
                     self.fetching = false;
                     self.updateHash();
                 }
@@ -478,9 +478,8 @@ var app = new Vue({
             );
         },
 
-        getListColumns: function ( collName ) {
-            var coll = this.collections[ collName ],
-                schema = coll.operations["list"].schema,
+        getListColumns: function ( schemaName ) {
+            var schema = this.schema[ schemaName ].operations["list"].schema,
                 props = schema.properties,
                 columns = schema['x-list-columns'] || [];
             return columns.map( function (c) {
@@ -493,23 +492,22 @@ var app = new Vue({
 
         parseHash: function () {
             var parts = location.hash.split( '/' ),
-                collection = parts[1],
+                schema = parts[1],
                 page = parts[2];
             return {
-                collection: collection,
+                schema: schema,
                 page: page
             };
         },
 
         updateHash: function () {
-            location.hash = "/" + this.currentCollection + "/" + this.currentPage;
+            location.hash = "/" + this.currentSchemaName + "/" + this.currentPage;
         },
 
         saveItem: function (i) {
             var self = this,
-                coll = this.collections[ this.currentCollection ],
-                value = this.prepareSaveItem( this.items[i], coll.operations['set'].schema ),
-                url = this.fillUrl( coll.operations['set'].url, this.openedOldValue );
+                value = this.prepareSaveItem( this.items[i], this.currentOperations['set'].schema ),
+                url = this.fillUrl( this.currentOperations['set'].url, this.openedOldValue );
             delete this.error.saveItem;
             this.$set( this, 'formError', {} );
             $.ajax(
@@ -523,10 +521,7 @@ var app = new Vue({
                 function ( data, status, jqXHR ) {
                     self.items[i] = data;
                     self.toggleRow( i );
-                    self.$set( self.info, 'saveItem', true );
-                    setTimeout( function () {
-                        self.$set( self.info, 'saveItem', false );
-                    }, 5000 );
+                    self.addToast( { icon: "fa-save", title: "Saved", text: "Item saved" } );
                 }
             ).fail(
                 function ( jqXHR, textStatus, errorThrown ) {
@@ -543,9 +538,9 @@ var app = new Vue({
 
         addItem: function () {
             var self = this,
-                coll = this.collections[ this.currentCollection ],
-                value = this.prepareSaveItem( this.newItem, coll.operations['add'].schema ),
-                url = coll.operations['add'].url;
+                schema = this.currentSchema,
+                value = this.prepareSaveItem( this.newItem, schema ),
+                url = this.currentOperations['add'].url;
             delete this.error.addItem;
             this.$set( this, 'formError', {} );
             $.ajax(
@@ -557,13 +552,13 @@ var app = new Vue({
                 }
             ).done(
                 function ( data, status, jqXHR ) {
-                    var id = coll.operations['add'].schema['x-id-field'] || 'id';
+                    var id = self.currentOperations['add'].schema['x-id-field'] || 'id';
                     var urlParams = {};
                     urlParams[ id ] = data;
 
                     $.ajax(
                         {
-                            url: self.fillUrl( coll.operations['get'].url, urlParams ),
+                            url: self.fillUrl( self.currentOperations['get'].url, urlParams ),
                             method: 'GET',
                             dataType: 'json'
                         }
@@ -572,10 +567,7 @@ var app = new Vue({
                             self.items.unshift( data );
                             self.total++;
                             self.cancelAddItem();
-                            self.$set( self.info, 'addItem', true );
-                            setTimeout( function () {
-                                self.$set( self.info, 'addItem', false );
-                            }, 5000 );
+                            self.addToast( { icon: "fa-save", title: "Added", text: "Item added" } );
                         }
                     ).fail(
                         function ( jqXHR, textStatus, errorThrown ) {
@@ -659,7 +651,7 @@ var app = new Vue({
         },
 
         createBlankItem: function () {
-            var schema = this.collections[ this.currentCollection ].operations['add'].schema,
+            var schema = this.currentSchema,
                 item = {};
             if ( schema.example ) {
                 return schema.example;
@@ -683,9 +675,9 @@ var app = new Vue({
         deleteItem: function () {
             var i = this.deleteIndex,
                 self = this,
-                coll = this.collections[ this.currentCollection ],
+                schema = this.currentSchema,
                 value = $( '#data-' + i ).val(),
-                url = this.fillUrl( coll.operations['delete'].url, this.items[i] );
+                url = this.fillUrl( this.currentOperations['delete'].url, this.items[i] );
             $.ajax(
                 {
                     url: url,
@@ -717,8 +709,8 @@ var app = new Vue({
         },
 
         renderValue: function ( field, value ) {
-            var coll = this.schema;
-            var fieldType = coll.properties[ field ].type;
+            var schema = this.currentSchema;
+            var fieldType = schema.properties[ field ].type;
             var type = Array.isArray( fieldType ) ? fieldType[0] : fieldType;
             if ( type == 'boolean' ) {
                 return value ? 'Yes' : 'No';
@@ -727,7 +719,21 @@ var app = new Vue({
         },
 
         rowViewUrl: function ( data ) {
-            return this.fillUrl( this.schema[ 'x-view-item-url' ], data );
+            return this.fillUrl( this.currentSchema[ 'x-view-item-url' ], data );
+        },
+
+        addToast: function ( toast ) {
+            var self = this;
+            this.toasts.push( toast );
+            setTimeout(
+                function ( toast ) { self.removeToast( toast ) },
+                5000,
+                toast
+            );
+        },
+
+        removeToast: function ( toast ) {
+            this.toasts.splice( this.toasts.indexOf( toast ), 1 );
         }
 
     },
@@ -757,15 +763,15 @@ var app = new Vue({
             return pages;
         },
 
-        operations: function () {
-            return this.collections[ this.currentCollection ] ? this.collections[ this.currentCollection ].operations : {};
+        currentOperations: function () {
+            return this.schema[ this.currentSchemaName ] ? this.schema[ this.currentSchemaName ].operations : {};
         },
-        schema: function () {
-            return this.operations.get ? this.operations.get.schema : {};
+        currentSchema: function () {
+            return this.currentOperations.get ? this.currentOperations.get.schema : {};
         }
     },
     watch: {
-        currentCollection: function () {
+        currentSchemaName: function () {
             this.data = [];
             this.currentPage = 1;
             this.openedRow = null;
