@@ -1,5 +1,5 @@
 package Yancy::Backend::Sqlite;
-our $VERSION = '1.025';
+our $VERSION = '1.026';
 # ABSTRACT: A backend for SQLite using Mojo::SQLite
 
 #pod =head1 SYNOPSIS
@@ -51,9 +51,9 @@ our $VERSION = '1.025';
 #pod     # In a specific location
 #pod     sqlite:/tmp/filename.db
 #pod
-#pod =head2 Collections
+#pod =head2 Schema Names
 #pod
-#pod The collections for this backend are the names of the tables in the
+#pod The schema names for this backend are the names of the tables in the
 #pod database.
 #pod
 #pod So, if you have the following schema:
@@ -69,11 +69,11 @@ our $VERSION = '1.025';
 #pod         email VARCHAR NULL
 #pod     );
 #pod
-#pod You could map that schema to the following collections:
+#pod You could map that to the following schema:
 #pod
 #pod     {
 #pod         backend => 'sqlite:filename.db',
-#pod         collections => {
+#pod         schema => {
 #pod             People => {
 #pod                 required => [ 'name', 'email' ],
 #pod                 properties => {
@@ -123,7 +123,13 @@ BEGIN {
         or die "Could not load SQLite backend: Mojo::SQLite version 3 or higher required\n";
 }
 
-has collections =>;
+has schema =>;
+sub collections {
+    require Carp;
+    Carp::carp( '"collections" method is now "schema"' );
+    shift->schema( @_ );
+}
+
 has mojodb =>;
 use constant mojodb_class => 'Mojo::SQLite';
 use constant mojodb_prefix => 'sqlite';
@@ -134,12 +140,12 @@ sub dbcatalog { undef }
 sub dbschema { undef }
 
 sub create {
-    my ( $self, $coll, $params ) = @_;
-    $params = $self->normalize( $coll, $params );
-    die "No refs allowed in '$coll': " . encode_json $params
+    my ( $self, $schema_name, $params ) = @_;
+    $params = $self->normalize( $schema_name, $params );
+    die "No refs allowed in '$schema_name': " . encode_json $params
         if grep ref, values %$params;
-    my $id_field = $self->id_field( $coll );
-    my $inserted_id = $self->mojodb->db->insert( $coll, $params )->last_insert_id;
+    my $id_field = $self->id_field( $schema_name );
+    my $inserted_id = $self->mojodb->db->insert( $schema_name, $params )->last_insert_id;
     # SQLite does not have a 'returning' syntax. Assume id field is correct
     # if passed, created otherwise:
     return $params->{$id_field} || $inserted_id;
@@ -199,7 +205,7 @@ Yancy::Backend::Sqlite - A backend for SQLite using Mojo::SQLite
 
 =head1 VERSION
 
-version 1.025
+version 1.026
 
 =head1 SYNOPSIS
 
@@ -250,9 +256,9 @@ Some examples:
     # In a specific location
     sqlite:/tmp/filename.db
 
-=head2 Collections
+=head2 Schema Names
 
-The collections for this backend are the names of the tables in the
+The schema names for this backend are the names of the tables in the
 database.
 
 So, if you have the following schema:
@@ -268,11 +274,11 @@ So, if you have the following schema:
         email VARCHAR NULL
     );
 
-You could map that schema to the following collections:
+You could map that to the following schema:
 
     {
         backend => 'sqlite:filename.db',
-        collections => {
+        schema => {
             People => {
                 required => [ 'name', 'email' ],
                 properties => {
@@ -316,7 +322,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Doug Bell.
+This software is copyright (c) 2019 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
