@@ -1,12 +1,12 @@
 package Yancy::Controller::Yancy;
-our $VERSION = '1.025';
+our $VERSION = '1.026';
 # ABSTRACT: Basic controller for displaying content
 
 #pod =head1 SYNOPSIS
 #pod
 #pod     use Mojolicious::Lite;
 #pod     plugin Yancy => {
-#pod         collections => {
+#pod         schema => {
 #pod             blog => {
 #pod                 properties => {
 #pod                     id => { type => 'integer' },
@@ -19,7 +19,7 @@ our $VERSION = '1.025';
 #pod
 #pod     app->routes->get( '/' )->to(
 #pod         'yancy#list',
-#pod         collection => 'blog',
+#pod         schema => 'blog',
 #pod         template => 'index',
 #pod     );
 #pod
@@ -33,7 +33,7 @@ our $VERSION = '1.025';
 #pod =head1 DESCRIPTION
 #pod
 #pod This controller contains basic route handlers for displaying content
-#pod configured in Yancy collections. These route handlers reduce the amount
+#pod configured in Yancy schema. These route handlers reduce the amount
 #pod of code you need to write to display or modify your content.
 #pod
 #pod Route handlers use the Mojolicious C<stash> for configuration. These values
@@ -103,12 +103,13 @@ our $VERSION = '1.025';
 #pod =cut
 
 use Mojo::Base 'Mojolicious::Controller';
+use Yancy::Util qw( derp );
 
 #pod =method list
 #pod
 #pod     $routes->get( '/' )->to(
 #pod         'yancy#list',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod     );
 #pod
@@ -118,9 +119,9 @@ use Mojo::Base 'Mojolicious::Controller';
 #pod
 #pod =over
 #pod
-#pod =item collection
+#pod =item schema
 #pod
-#pod The collection to use. Required.
+#pod The schema to use. Required.
 #pod
 #pod =item template
 #pod
@@ -161,8 +162,11 @@ use Mojo::Base 'Mojolicious::Controller';
 
 sub list {
     my ( $c ) = @_;
-    my $coll_name = $c->stash( 'collection' )
-        || die "Collection name not defined in stash";
+    if ( $c->stash( 'collection' ) ) {
+        derp '"collection" stash key is now "schema" in controller configuration';
+    }
+    my $schema_name = $c->stash( 'schema' ) || $c->stash( 'collection' )
+        || die "Schema name not defined in stash";
     my $limit = $c->stash->{ limit } //= 10;
     my $page = $c->stash->{ page } //= 1;
     my $offset = ( $page - 1 ) * $limit;
@@ -173,7 +177,7 @@ sub list {
     my $filter = {
         %{ $c->stash( 'filter' ) || {} },
     };
-    my $items = $c->yancy->backend->list( $coll_name, $filter, $opt );
+    my $items = $c->yancy->backend->list( $schema_name, $filter, $opt );
     return $c->respond_to(
         json => sub {
             $c->stash( json => { %$items, offset => $offset } );
@@ -191,7 +195,7 @@ sub list {
 #pod
 #pod     $routes->get( '/:id' )->to(
 #pod         'yancy#get',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod     );
 #pod
@@ -201,13 +205,13 @@ sub list {
 #pod
 #pod =over
 #pod
-#pod =item collection
+#pod =item schema
 #pod
-#pod The collection to use. Required.
+#pod The schema to use. Required.
 #pod
 #pod =item id
 #pod
-#pod The ID of the item from the collection. Required. Usually part of
+#pod The ID of the item from the schema. Required. Usually part of
 #pod the route path as a placeholder.
 #pod
 #pod =item template
@@ -231,10 +235,13 @@ sub list {
 
 sub get {
     my ( $c ) = @_;
-    my $coll_name = $c->stash( 'collection' )
-        || die "Collection name not defined in stash";
+    if ( $c->stash( 'collection' ) ) {
+        derp '"collection" stash key is now "schema" in controller configuration';
+    }
+    my $schema_name = $c->stash( 'schema' ) || $c->stash( 'collection' )
+        || die "Schema name not defined in stash";
     my $id = $c->stash( 'id' ) // die 'ID not defined in stash';
-    my $item = $c->yancy->backend->get( $coll_name => $id );
+    my $item = $c->yancy->backend->get( $schema_name => $id );
     if ( !$item ) {
         $c->reply->not_found;
         return;
@@ -249,23 +256,23 @@ sub get {
 #pod
 #pod     $routes->any( [ 'GET', 'POST' ] => '/:id/edit' )->to(
 #pod         'yancy#set',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod     );
 #pod
 #pod     $routes->any( [ 'GET', 'POST' ] => '/create' )->to(
 #pod         'yancy#set',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod         forward_to => $route_name,
 #pod     );
 #pod
 #pod This route creates a new item or updates an existing item in
-#pod a collection. If the user is making a C<GET> request, they will simply
+#pod a schema. If the user is making a C<GET> request, they will simply
 #pod be shown the template. If the user is making a C<POST> or C<PUT>
 #pod request, the form parameters will be read, the data will be validated
-#pod against L<the collection configuration|Yancy::Help::Config/Data
-#pod Collections>, and the user will either be shown the form again with the
+#pod against L<the schema configuration|Yancy::Help::Config/Data
+#pod Schema>, and the user will either be shown the form again with the
 #pod result of the form submission (success or failure) or the user will be
 #pod forwarded to another place.
 #pod
@@ -273,13 +280,13 @@ sub get {
 #pod
 #pod =over
 #pod
-#pod =item collection
+#pod =item schema
 #pod
-#pod The collection to use. Required.
+#pod The schema to use. Required.
 #pod
 #pod =item id
 #pod
-#pod The ID of the item from the collection. Optional: If not specified, a new
+#pod The ID of the item from the schema. Optional: If not specified, a new
 #pod item will be created. Usually part of the route path as a placeholder.
 #pod
 #pod =item template
@@ -295,7 +302,7 @@ sub get {
 #pod     $routes->get( '/:id/:slug' )->name( 'blog.view' );
 #pod     $routes->post( '/create' )->to(
 #pod         'yancy#set',
-#pod         collection => 'blog',
+#pod         schema => 'blog',
 #pod         template => 'blog_edit.html.ep',
 #pod         forward_to => 'blog.view',
 #pod     );
@@ -313,7 +320,7 @@ sub get {
 #pod
 #pod B<NOTE:> Unless restricted to certain properties using this
 #pod configuration, this method accepts all valid data configured for the
-#pod collection. The data being submitted can be more than just the fields
+#pod schema. The data being submitted can be more than just the fields
 #pod you make available in the form. If you do not want certain data to be
 #pod written through this form, you can prevent it by using this.
 #pod
@@ -358,12 +365,12 @@ sub get {
 #pod
 #pod     $routes->get( '/:id/edit' )->to(
 #pod         'yancy#get',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod     );
 #pod     $routes->post( '/:id/edit' )->to(
 #pod         'yancy#set',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod     );
 #pod
@@ -371,8 +378,11 @@ sub get {
 
 sub set {
     my ( $c ) = @_;
-    my $coll_name = $c->stash( 'collection' )
-        || die "Collection name not defined in stash";
+    if ( $c->stash( 'collection' ) ) {
+        derp '"collection" stash key is now "schema" in controller configuration';
+    }
+    my $schema_name = $c->stash( 'schema' ) || $c->stash( 'collection' )
+        || die "Schema name not defined in stash";
     my $id = $c->stash( 'id' );
 
     # Display the form, if requested. This makes the simple case of
@@ -380,9 +390,9 @@ sub set {
     # of two routes (one to "yancy#get" and one to "yancy#set")
     if ( $c->req->method eq 'GET' ) {
         if ( $id ) {
-            my $item = $c->yancy->get( $coll_name => $id );
+            my $item = $c->yancy->get( $schema_name => $id );
             $c->stash( item => $item );
-            my $props = $c->yancy->schema( $coll_name )->{properties};
+            my $props = $c->yancy->schema( $schema_name )->{properties};
             for my $key ( keys %$props ) {
                 # Mojolicious TagHelpers take current values through the
                 # params, but also we allow pre-filling values through the
@@ -413,7 +423,7 @@ sub set {
         $c->app->log->error( 'CSRF token validation failed' );
         $c->render(
             status => 400,
-            item => $c->yancy->get( $coll_name => $id ),
+            item => $c->yancy->get( $schema_name => $id ),
             errors => [
                 {
                     message => 'CSRF token invalid.',
@@ -428,7 +438,7 @@ sub set {
     #; use Data::Dumper;
     #; $c->app->log->debug( Dumper $data );
 
-    my $props = $c->yancy->schema( $coll_name )->{properties};
+    my $props = $c->yancy->schema( $schema_name )->{properties};
     for my $key ( keys %$props ) {
         my $format = $props->{ $key }{ format };
         # Password cannot be changed to an empty string
@@ -448,10 +458,10 @@ sub set {
 
     my $update = $id ? 1 : 0;
     if ( $update ) {
-        eval { $c->yancy->set( $coll_name, $id, $data, %opt ) };
+        eval { $c->yancy->set( $schema_name, $id, $data, %opt ) };
     }
     else {
-        $id = eval { $c->yancy->create( $coll_name, $data ) };
+        $id = eval { $c->yancy->create( $schema_name, $data ) };
     }
 
     if ( my $errors = $@ ) {
@@ -464,7 +474,7 @@ sub set {
             $c->res->code( 500 );
             $errors = [ { message => $errors } ];
         }
-        my $item = $c->yancy->get( $coll_name, $id );
+        my $item = $c->yancy->get( $schema_name, $id );
         $c->respond_to(
             json => { json => { errors => $errors } },
             html => { item => $item, errors => $errors },
@@ -472,7 +482,7 @@ sub set {
         return;
     }
 
-    my $item = $c->yancy->get( $coll_name, $id );
+    my $item = $c->yancy->get( $schema_name, $id );
     return $c->respond_to(
         json => sub {
             $c->stash(
@@ -494,12 +504,12 @@ sub set {
 #pod
 #pod     $routes->any( [ 'GET', 'POST' ], '/delete/:id' )->to(
 #pod         'yancy#delete',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod         forward_to => $route_name,
 #pod     );
 #pod
-#pod This route deletes an item from a collection. If the user is making
+#pod This route deletes an item from a schema. If the user is making
 #pod a C<GET> request, they will simply be shown the template (which can be
 #pod used to confirm the delete). If the user is making a C<POST> or C<DELETE>
 #pod request, the item will be deleted and the user will either be shown the
@@ -510,13 +520,13 @@ sub set {
 #pod
 #pod =over
 #pod
-#pod =item collection
+#pod =item schema
 #pod
-#pod The collection to use. Required.
+#pod The schema to use. Required.
 #pod
 #pod =item id
 #pod
-#pod The ID of the item from the collection. Required. Usually part of the
+#pod The ID of the item from the schema. Required. Usually part of the
 #pod route path as a placeholder.
 #pod
 #pod =item template
@@ -554,14 +564,17 @@ sub set {
 
 sub delete {
     my ( $c ) = @_;
-    my $coll_name = $c->stash( 'collection' )
-        || die "Collection name not defined in stash";
+    if ( $c->stash( 'collection' ) ) {
+        derp '"collection" stash key is now "schema" in controller configuration';
+    }
+    my $schema_name = $c->stash( 'schema' ) || $c->stash( 'collection' )
+        || die "Schema name not defined in stash";
     my $id = $c->stash( 'id' ) // die 'ID not defined in stash';
 
     # Display the form, if requested. This makes it easy to display
     # a confirmation page in a single route.
     if ( $c->req->method eq 'GET' ) {
-        my $item = $c->yancy->get( $coll_name => $id );
+        my $item = $c->yancy->get( $schema_name => $id );
         $c->respond_to(
             json => {
                 status => 400,
@@ -582,7 +595,7 @@ sub delete {
         $c->app->log->error( 'CSRF token validation failed' );
         $c->render(
             status => 400,
-            item => $c->yancy->get( $coll_name => $id ),
+            item => $c->yancy->get( $schema_name => $id ),
             errors => [
                 {
                     message => 'CSRF token invalid.',
@@ -592,7 +605,7 @@ sub delete {
         return;
     }
 
-    $c->yancy->delete( $coll_name, $id );
+    $c->yancy->delete( $schema_name, $id );
 
     return $c->respond_to(
         json => sub {
@@ -620,13 +633,13 @@ Yancy::Controller::Yancy - Basic controller for displaying content
 
 =head1 VERSION
 
-version 1.025
+version 1.026
 
 =head1 SYNOPSIS
 
     use Mojolicious::Lite;
     plugin Yancy => {
-        collections => {
+        schema => {
             blog => {
                 properties => {
                     id => { type => 'integer' },
@@ -639,7 +652,7 @@ version 1.025
 
     app->routes->get( '/' )->to(
         'yancy#list',
-        collection => 'blog',
+        schema => 'blog',
         template => 'index',
     );
 
@@ -653,7 +666,7 @@ version 1.025
 =head1 DESCRIPTION
 
 This controller contains basic route handlers for displaying content
-configured in Yancy collections. These route handlers reduce the amount
+configured in Yancy schema. These route handlers reduce the amount
 of code you need to write to display or modify your content.
 
 Route handlers use the Mojolicious C<stash> for configuration. These values
@@ -670,7 +683,7 @@ L<Mojolicious::Guides::Rendering/Content negotiation>.
 
     $routes->get( '/' )->to(
         'yancy#list',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
     );
 
@@ -680,9 +693,9 @@ This method uses the following stash values for configuration:
 
 =over
 
-=item collection
+=item schema
 
-The collection to use. Required.
+The schema to use. Required.
 
 =item template
 
@@ -723,7 +736,7 @@ The number of pages of items. Can be used for pagination.
 
     $routes->get( '/:id' )->to(
         'yancy#get',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
     );
 
@@ -733,13 +746,13 @@ This method uses the following stash values for configuration:
 
 =over
 
-=item collection
+=item schema
 
-The collection to use. Required.
+The schema to use. Required.
 
 =item id
 
-The ID of the item from the collection. Required. Usually part of
+The ID of the item from the schema. Required. Usually part of
 the route path as a placeholder.
 
 =item template
@@ -763,23 +776,23 @@ The item that is being displayed.
 
     $routes->any( [ 'GET', 'POST' ] => '/:id/edit' )->to(
         'yancy#set',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
     );
 
     $routes->any( [ 'GET', 'POST' ] => '/create' )->to(
         'yancy#set',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
         forward_to => $route_name,
     );
 
 This route creates a new item or updates an existing item in
-a collection. If the user is making a C<GET> request, they will simply
+a schema. If the user is making a C<GET> request, they will simply
 be shown the template. If the user is making a C<POST> or C<PUT>
 request, the form parameters will be read, the data will be validated
-against L<the collection configuration|Yancy::Help::Config/Data
-Collections>, and the user will either be shown the form again with the
+against L<the schema configuration|Yancy::Help::Config/Data
+Schema>, and the user will either be shown the form again with the
 result of the form submission (success or failure) or the user will be
 forwarded to another place.
 
@@ -787,13 +800,13 @@ This method uses the following stash values for configuration:
 
 =over
 
-=item collection
+=item schema
 
-The collection to use. Required.
+The schema to use. Required.
 
 =item id
 
-The ID of the item from the collection. Optional: If not specified, a new
+The ID of the item from the schema. Optional: If not specified, a new
 item will be created. Usually part of the route path as a placeholder.
 
 =item template
@@ -809,7 +822,7 @@ route placeholders that match item field names will be filled in.
     $routes->get( '/:id/:slug' )->name( 'blog.view' );
     $routes->post( '/create' )->to(
         'yancy#set',
-        collection => 'blog',
+        schema => 'blog',
         template => 'blog_edit.html.ep',
         forward_to => 'blog.view',
     );
@@ -827,7 +840,7 @@ will result in an error.
 
 B<NOTE:> Unless restricted to certain properties using this
 configuration, this method accepts all valid data configured for the
-collection. The data being submitted can be more than just the fields
+schema. The data being submitted can be more than just the fields
 you make available in the form. If you do not want certain data to be
 written through this form, you can prevent it by using this.
 
@@ -872,12 +885,12 @@ method, but with more code:
 
     $routes->get( '/:id/edit' )->to(
         'yancy#get',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
     );
     $routes->post( '/:id/edit' )->to(
         'yancy#set',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
     );
 
@@ -885,12 +898,12 @@ method, but with more code:
 
     $routes->any( [ 'GET', 'POST' ], '/delete/:id' )->to(
         'yancy#delete',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
         forward_to => $route_name,
     );
 
-This route deletes an item from a collection. If the user is making
+This route deletes an item from a schema. If the user is making
 a C<GET> request, they will simply be shown the template (which can be
 used to confirm the delete). If the user is making a C<POST> or C<DELETE>
 request, the item will be deleted and the user will either be shown the
@@ -901,13 +914,13 @@ This method uses the following stash values for configuration:
 
 =over
 
-=item collection
+=item schema
 
-The collection to use. Required.
+The schema to use. Required.
 
 =item id
 
-The ID of the item from the collection. Required. Usually part of the
+The ID of the item from the schema. Required. Usually part of the
 route path as a placeholder.
 
 =item template
@@ -1003,7 +1016,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Doug Bell.
+This software is copyright (c) 2019 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
