@@ -1,12 +1,12 @@
 package Yancy::Controller::Yancy::MultiTenant;
-our $VERSION = '1.025';
+our $VERSION = '1.026';
 # ABSTRACT: A controller to show a user only their content
 
 #pod =head1 SYNOPSIS
 #pod
 #pod     use Mojolicious::Lite;
 #pod     plugin Yancy => {
-#pod         collections => {
+#pod         schema => {
 #pod             blog => {
 #pod                 properties => {
 #pod                     id => { type => 'integer' },
@@ -20,7 +20,7 @@ our $VERSION = '1.025';
 #pod
 #pod     app->routes->get( '/user/:user_id' )->to(
 #pod         'yancy-multi_tenant#list',
-#pod         collection => 'blog',
+#pod         schema => 'blog',
 #pod         template => 'index'
 #pod     );
 #pod
@@ -60,13 +60,13 @@ our $VERSION = '1.025';
 #pod     # /:username - List blog posts
 #pod     $user_route->get( '' )->to(
 #pod         'yancy-multi_tenant#list',
-#pod         collection => 'blog',
+#pod         schema => 'blog',
 #pod         template => 'blog_list',
 #pod     );
 #pod     # /:username/:id/:slug - Get a single blog post
 #pod     $user_route->get( '/:id/:slug' )->to(
 #pod         'yancy-multi_tenant#get',
-#pod         collection => 'blog',
+#pod         schema => 'blog',
 #pod         template => 'blog_view',
 #pod     );
 #pod
@@ -77,7 +77,7 @@ our $VERSION = '1.025';
 #pod
 #pod     app->yancy->plugin( 'Auth::Basic', {
 #pod         route => any( '' ), # All routes require login
-#pod         collection => 'user',
+#pod         schema => 'user',
 #pod         username_field => 'username',
 #pod         password_digest => { type => 'SHA-1' },
 #pod     } );
@@ -92,7 +92,7 @@ our $VERSION = '1.025';
 #pod     # / - List todo items
 #pod     $user_route->get( '' )->to(
 #pod         'yancy-multi_tenant#list',
-#pod         collection => 'todo_item',
+#pod         schema => 'todo_item',
 #pod         template => 'todo_list',
 #pod     );
 #pod
@@ -103,12 +103,13 @@ our $VERSION = '1.025';
 #pod =cut
 
 use Mojo::Base 'Yancy::Controller::Yancy';
+use Yancy::Util qw( derp );
 
 #pod =method list
 #pod
 #pod     $routes->get( '/:user_id' )->to(
 #pod         'yancy-multi_tenant#list',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod     );
 #pod
@@ -147,7 +148,7 @@ sub list {
 #pod
 #pod     $routes->get( '/:user_id/:id' )->to(
 #pod         'yancy-multi_tenant#get',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod     );
 #pod
@@ -182,22 +183,22 @@ sub get {
 #pod
 #pod     $routes->any( [ 'GET', 'POST' ] => '/:id/edit' )->to(
 #pod         'yancy#set',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod     );
 #pod
 #pod     $routes->any( [ 'GET', 'POST' ] => '/create' )->to(
 #pod         'yancy#set',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod         forward_to => $route_name,
 #pod     );
 #pod
 #pod This route creates a new item or updates an existing item in
-#pod a collection. If the user is making a C<GET> request, they will simply
+#pod a schema. If the user is making a C<GET> request, they will simply
 #pod be shown the template. If the user is making a C<POST> or C<PUT>
 #pod request, the form parameters will be read, the data will be validated
-#pod against L<the collection configuration|Yancy::Help::Config/Data
+#pod against L<the schema configuration|Yancy::Help::Config/Data
 #pod Collections>, and the user will either be shown the form again with the
 #pod result of the form submission (success or failure) or the user will be
 #pod forwarded to another place.
@@ -244,12 +245,12 @@ sub set {
 #pod
 #pod     $routes->any( [ 'GET', 'POST' ], '/delete/:id' )->to(
 #pod         'yancy#delete',
-#pod         collection => $collection_name,
+#pod         schema => $schema_name,
 #pod         template => $template_name,
 #pod         forward_to => $route_name,
 #pod     );
 #pod
-#pod This route deletes an item from a collection. If the user is making
+#pod This route deletes an item from a schema. If the user is making
 #pod a C<GET> request, they will simply be shown the template (which can be
 #pod used to confirm the delete). If the user is making a C<POST> or C<DELETE>
 #pod request, the item will be deleted and the user will either be shown the
@@ -290,17 +291,20 @@ sub delete {
 #   return if !_is_owned_by();
 #
 # Check that the currently-requested item is owned by the user_id in the
-# stash. This uses the collection, id, user_id, and user_id_field stash
+# stash. This uses the schema, id, user_id, and user_id_field stash
 # values. user_id_field defaults to 'user_id'. All other fields are
 # required and will throw an exception if missing.
 sub _is_owned_by {
     my ( $c ) = @_;
-    my $coll_name = $c->stash( 'collection' )
-        || die "Collection name not defined in stash";
+    if ( $c->stash( 'collection' ) ) {
+        derp '"collection" stash key is now "schema" in controller configuration';
+    }
+    my $schema_name = $c->stash( 'schema' ) || $c->stash( 'collection' )
+        || die "Schema name not defined in stash";
     my $user_id = $c->stash( 'user_id' ) || die "User ID not defined in stash";
     my $id = $c->stash( 'id' ) // die 'ID not defined in stash';
     my $user_id_field = $c->stash( 'user_id_field' ) // 'user_id';
-    my $item = $c->yancy->backend->get( $coll_name => $id );
+    my $item = $c->yancy->backend->get( $schema_name => $id );
     if ( !$item || $item->{ $user_id_field } ne $user_id ) {
         $c->reply->not_found;
         return 0;
@@ -320,13 +324,13 @@ Yancy::Controller::Yancy::MultiTenant - A controller to show a user only their c
 
 =head1 VERSION
 
-version 1.025
+version 1.026
 
 =head1 SYNOPSIS
 
     use Mojolicious::Lite;
     plugin Yancy => {
-        collections => {
+        schema => {
             blog => {
                 properties => {
                     id => { type => 'integer' },
@@ -340,7 +344,7 @@ version 1.025
 
     app->routes->get( '/user/:user_id' )->to(
         'yancy-multi_tenant#list',
-        collection => 'blog',
+        schema => 'blog',
         template => 'index'
     );
 
@@ -366,7 +370,7 @@ by a user's ID.
 
     $routes->get( '/:user_id' )->to(
         'yancy-multi_tenant#list',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
     );
 
@@ -393,7 +397,7 @@ The field in the item that holds the user ID. Defaults to C<user_id>.
 
     $routes->get( '/:user_id/:id' )->to(
         'yancy-multi_tenant#get',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
     );
 
@@ -420,22 +424,22 @@ The field in the item that holds the user ID. Defaults to C<user_id>.
 
     $routes->any( [ 'GET', 'POST' ] => '/:id/edit' )->to(
         'yancy#set',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
     );
 
     $routes->any( [ 'GET', 'POST' ] => '/create' )->to(
         'yancy#set',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
         forward_to => $route_name,
     );
 
 This route creates a new item or updates an existing item in
-a collection. If the user is making a C<GET> request, they will simply
+a schema. If the user is making a C<GET> request, they will simply
 be shown the template. If the user is making a C<POST> or C<PUT>
 request, the form parameters will be read, the data will be validated
-against L<the collection configuration|Yancy::Help::Config/Data
+against L<the schema configuration|Yancy::Help::Config/Data
 Collections>, and the user will either be shown the form again with the
 result of the form submission (success or failure) or the user will be
 forwarded to another place.
@@ -465,12 +469,12 @@ This field will be filled in with the C<user_id> stash value.
 
     $routes->any( [ 'GET', 'POST' ], '/delete/:id' )->to(
         'yancy#delete',
-        collection => $collection_name,
+        schema => $schema_name,
         template => $template_name,
         forward_to => $route_name,
     );
 
-This route deletes an item from a collection. If the user is making
+This route deletes an item from a schema. If the user is making
 a C<GET> request, they will simply be shown the template (which can be
 used to confirm the delete). If the user is making a C<POST> or C<DELETE>
 request, the item will be deleted and the user will either be shown the
@@ -518,13 +522,13 @@ in the path to the ID:
     # /:username - List blog posts
     $user_route->get( '' )->to(
         'yancy-multi_tenant#list',
-        collection => 'blog',
+        schema => 'blog',
         template => 'blog_list',
     );
     # /:username/:id/:slug - Get a single blog post
     $user_route->get( '/:id/:slug' )->to(
         'yancy-multi_tenant#get',
-        collection => 'blog',
+        schema => 'blog',
         template => 'blog_view',
     );
 
@@ -535,7 +539,7 @@ C<user_id> from the current user.
 
     app->yancy->plugin( 'Auth::Basic', {
         route => any( '' ), # All routes require login
-        collection => 'user',
+        schema => 'user',
         username_field => 'username',
         password_digest => { type => 'SHA-1' },
     } );
@@ -550,7 +554,7 @@ C<user_id> from the current user.
     # / - List todo items
     $user_route->get( '' )->to(
         'yancy-multi_tenant#list',
-        collection => 'todo_item',
+        schema => 'todo_item',
         template => 'todo_list',
     );
 
@@ -564,7 +568,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Doug Bell.
+This software is copyright (c) 2019 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
